@@ -1,8 +1,8 @@
 /* -*-C-*-
 
-$Id: utils.h,v 1.1 2003/06/12 05:30:49 cph Exp $
+$Id: utils.h,v 1.2 2005/03/01 21:26:59 cph Exp $
 
-Copyright 2003 Massachusetts Institute of Technology
+Copyright 2003,2004 Massachusetts Institute of Technology
 
 This file is part of autonet.
 
@@ -31,5 +31,7 @@ extern void * xrealloc (void *, unsigned long);
 extern char * copy_string (const char *);
 extern void log_perror (const char *);
 extern void log_error (const char *);
+extern char * read_line (FILE *);
+extern double get_real_time (void);
 
 #endif /* not AUTONET_UTILS_H */
